
MonitorViewModel = class(ViewModelBase);

-- Initializes a new MonitorViewModel instance
function MonitorViewModel:Constructor(filterEngine)
	ViewModelBase.Constructor(self);
	
	-- private
	self.Engine = filterEngine;
	
	-- public
	self.Title = "Monitor";
	self.Stats = {};

	-- update stats so that we have some data on start up
	self:UpdateStats();

	self:AddCallback(self.Engine, "MessageCompleted", function()
		self:UpdateStats();
		self:RaisePropertyChanged("Stats");
	end);
end

-- private
function MonitorViewModel:UpdateStats()
	local stats = {};
	
	table.insert(stats, {Name = "Memory",              Value = string.format("%.2f", collectgarbage("count") / 1024) .. " MB"});
	table.insert(stats, {Name = "Chat Quality",        Value = string.format("%.2f", self.Engine.Data.ChatQuality)});
	table.insert(stats, {Name = "Chat Message Length", Value = string.format("%.2f", self.Engine.Data.ChatMessageLength)});
	table.insert(stats, {Name = "Messages Taken",      Value = self.Engine.Data.NumMessagesTaken});
	table.insert(stats, {Name = "Messages Blocked",    Value = self.Engine.Data.NumMessagesBlocked});

	for k, v in pairs(self.Engine.Data.BlockedByPolicy) do
		table.insert(stats, {Name = "Blocked by " .. k, Value = v});
	end

	self.Stats = stats;
end
